**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             centreValDeLoire_dynamic.gms
Sequence         3 - Modelling risk and time
Type             LP
GAMS language
Description

" An arable crop farmer that grows special crops (INOSYS Systme GC 131 data) in the Centre-Val de Loire region has 110 ha of land.
Irrigation and the economic environment of his farm offer him a large range of productions options :
soft wheat, durum wheat, spring barley, potato for human consumption, sugar beet and rapeseed.
Five of these crop types are irrigated in order to ensure high quality regular production.
The farmer has 60 000 m3 of water.

Irrigation needs and economic data are shown in the table below :

Irrigation water needs
Crops                                   Vol in m3/ha
Soft wheat                                  175
Durum wheat                                 350
Spring barley                               700
Potato for human consumption               1800
Sugar beet                                 1750

Other technico-economic data
Crops                          Yields (qx/ha)        Prices/qx ()        Total costs (/ha)
Soft wheat                         85                   16                    460
Durum wheat                        71                   28                    565
Spring barley                      70                   17.5                  470
Potato for human consumption      495                   14                   4210
Sugar beet                        950                    2.6                 1082
Rapeseed                           40                   38                    490

Source : from the Systme GC 131 of the INOSYS network of agricultural chambers in the Centre Val de Loire region. 2016

Crop yields depend on previous crops (a zero means that it is not possible to cultivate a given crop with that previous crop) :

Crops                                                 Previous crops
                                    Soft wheat        Durum wheat        Sugar beet       Rapeseed        Potato for human consumption        Barley
Soft wheat                              0                 80               85                85                     85                          80
Durum wheat                            65                  0               70                70                     70                          65
Sugar beet                            950                950                0                 0                      0                         950
Rapeseed                               40                 40                0                 0                      0                          40
Potato for human consumption          495               4954                0                 0                      0                         495
Barley                                 70                 60               70                70                     70                           0

The initial crop pattern is as follows : 10 ha of soft wheat, 20 ha of durum wheat, 30 ha of sugar beet, 0 ha of rapeseed, 40 ha of potato and 10 ha of barley.

The farmer maximizes his profit every year."

$Offtext


*----------                         DECLARATION                     ----------*
sets
C Crops               /SWheat, DWheat, SugarBeet, Rapeseed, Potato, Barley/
T periods of time     /T1*T10/
;

ALIAS(C,P)
*P  previous crop

*----------                          DATA                           ----------*
scalar
Land_A    Land availability            /110/
Water_A   Water availability           /60000/
;

parameter Water_Needs(C) water needs per crop and technology (m3 per ha)
/SWheat      175
 DWheat      350
 SugarBeet  1750
 Rapeseed      0
 Potato     1800
 Barley     700/
;

parameter
Pc (C) selling price per crop in euros
/SWheat    16
 DWheat    28
 SugarBeet     2.6
 Rapeseed   38
 Potato     14
 Barley    17.5/
;

parameter
VCost (C) variable cost per crop in euros per ha
/SWheat    460
 DWheat    565
 SugarBeet   1082
 Rapeseed   490
 Potato    4210
 Barley    470/
;

table
yields (C,P) yields per crop in quintals per ha
          SWheat    DWheat   SugarBeet   Rapeseed    Potato   Barley
 SWheat       0      80        85           85         85     80
 DWheat      65       0        70           70         70     65
 SugarBeet  950     950         0            0          0    950
 Rapeseed    40      40         0            0          0     40
 Potato     495     495         0            0          0    495
 Barley      70      60        70           70         70      0
;

parameter
GM(C,P) gross margin per crop in euros;
GM(C,P) = yields(C,P)*Pc(C)-VCost(C);

display GM ;

parameter
X_init(C) initial rotation
/SWheat   10,  DWheat    20,  SugarBeet   30,  Rapeseed   0,  Potato    40,  Barley   10/
;

*----------                         MODEL                           ----------*
variables
Z    total income  (euros)
;

positive variables
X(C,P)     area per crop (hectares)
;

equations
OBJECTIVE
LAND         LAND EQUATION
WATER        WATER EQUATION
ROT          ROTATION EQUATION
;

OBJECTIVE..     sum ((C,P), GM(C,P)* X(C,P)) =E= Z ;

LAND..          sum((C,P), X(C,P)) =l= Land_A  ;

WATER..         sum((C,P), Water_Needs(C)*X(C,P)) =l= Water_A  ;

ROT(P)..        sum(C, X(C,P)) =l= X_init(P);

model modelS2 first exemple /all/;

parameter result(*,*,*) ;

*----------                        SOLUTION                         ----------*
LOOP(t,

solve modelS2 using LP maximizing Z;
X_init(C)=sum(P,X.L(C,P));

result(C,P,t)=X.L(C,P)

);

display result;



